/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import DS from 'ember-data';

export default DS.Model.extend({
  startedOn: DS.attr('string'),
  state: DS.attr('string'),
  haState: DS.attr('string'),
  rmStateStoreName: DS.attr('string'),
  resourceManagerVersion: DS.attr('string'),
  resourceManagerBuildVersion: DS.attr('string'),
  hadoopVersion: DS.attr('string'),
  hadoopBuildVersion: DS.attr('string'),
  hadoopVersionBuiltOn: DS.attr('string'),
  getYARNBuildHash: function() {
	return this.get("hadoopVersion") + " from " +  this.get("resourceManagerBuildVersion").split(" ")[2];
  }.property("yarnHash")
});
